==> charlatan_0.2.2.tar.gz: charlatan/R/person-provider-lv_LV.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/lv_LV/__init__.py

person_formats_lv_lv = c(
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{last_names}}, {{first_names}}'
)

person_first_names_lv_lv = c(
  "\u0100dams",
  "\u0100dolfs",
  "Agris",
  "Aigars",
  "Ain\u0101rs",
  "Aivars",
  "Alberts",
  "Aldis",
  "Aleksandrs",
  "Alfr\u0113ds",
  "Andrejs",
  "Andris",
  "Andre\u0161s",
  "Ansis",
  "Antons",
  "Armands",
  "Arnis",
  "Arnolds",
  "Artis",
  "Arturs",
  "Art\u016brs",
  "Arv\u012bds",
  "Augusts",
  "B\u0113rends",
  "B\u0113rtulis",
  "Brencis",
  "Dainis",
  "Daniels",
  "D\u0101vis",
  "Dzintars",
  "Edgars",
  "Edmunds",
  "Eduards",
  "Edv\u012bns",
  "Egils",
  "Elm\u0101rs",
  "Elvis",
  "Em\u012bls",
  "\u0112riks",
  "Ermanis",
  "Ernests",
  "\u0112valds",
  "Fricis",
  "Gatis",
  "Gun\u0101rs",
  "Guntars",
  "Guntis",
  "\u0122ederts",
  "\u0122irts",
  "Hanss",
  "Harijs",
  "Henriks",
  "Hermanis",
  "Igors",
  "Ilm\u0101rs",
  "Imants",
  "Indri\u0137is",
  "Ivars",
  "Ivo",
  "Jakobs",
  "Janis",
  "J\u0101nis",
  "Jannis",
  "J\u0101zeps",
  "J\u0113kabs",
  "J\u0113kaubs",
  "Jezups",
  "Johans",
  "J\u016blijs",
  "Juris",
  "K\u0101rlis",
  "Kaspars",
  "Konradus",
  "Kristaps",
  "Kristers",
  "Krists",
  "Kri\u0161j\u0101nis",
  "Kri\u0161s",
  "Laimonis",
  "Lauris",
  "Leons",
  "Macs",
  "Mareks",
  "M\u0101ris",
  "M\u0101rti\u0146\u0161",
  "Mat\u012bss",
  "Mihels",
  "Mikels",
  "Mi\u0137elis",
  "Modris",
  "Nikolajs",
  "Niks",
  "Normunds",
  "O\u013c\u0123erts",
  "Oskars",
  "Osvalds",
  "Oto",
  "Pauls",
  "P\u0113teris",
  "Raimonds",
  "Raivis",
  "Reinis",
  "Ri\u010dards",
  "Rihards",
  "Roberts",
  "Rolands",
  "R\u016bdolfs",
  "Sandis",
  "Sta\u0146islavs",
  "Tenis",
  "Teodors",
  "Toms",
  "Uldis",
  "Valdis",
  "Viesturs",
  "Viktors",
  "Vilis",
  "Vilnis",
  "Vi\u013cums",
  "Visvaldis",
  "Vladislavs",
  "Voldem\u0101rs",
  "Ziedonis",
  "\u017danis",
  "Agnese",
  "Aiga",
  "Aija",
  "Aina",
  "Al\u012bda",
  "Alise",
  "Alma",
  "Alv\u012bne",
  "Am\u0101lija",
  "Anete",
  "Anita",
  "Anna",
  "Annija",
  "Anto\u0146ina",
  "Antra",
  "\u0100rija",
  "Ausma",
  "Austra",
  "Baba",
  "Baiba",
  "Berta",
  "Biruta",
  "Bro\u0146islava",
  "Dace",
  "Daiga",
  "Daina",
  "D\u0101rta",
  "Di\u0101na",
  "Doroteja",
  "Dzidra",
  "Dzintra",
  "Eda",
  "Ed\u012bte",
  "El\u012bna",
  "Elita",
  "Elizabete",
  "Elv\u012bra",
  "Elza",
  "Em\u012blija",
  "Emma",
  "\u0112rika",
  "Erna",
  "Eva",
  "Evija",
  "Evita",
  "Gaida",
  "Genovefa",
  "Gr\u0113ta",
  "Grieta",
  "Gunita",
  "Gunta",
  "Hel\u0113na",
  "Ieva",
  "Ilga",
  "Ilona",
  "Ilze",
  "Ina",
  "In\u0101ra",
  "Indra",
  "Inese",
  "Ineta",
  "Inga",
  "Ingr\u012bda",
  "Inguna",
  "Inta",
  "Ir\u0113na",
  "Irma",
  "Iveta",
  "Jana",
  "Janina",
  "J\u016ble",
  "J\u016bla",
  "J\u016blija",
  "Karina",
  "Karl\u012bna",
  "Katar\u012bna",
  "Katr\u012bna",
  "Krista",
  "Kristi\u0101na",
  "Laila",
  "Laura",
  "Lav\u012bze",
  "Leont\u012bne",
  "L\u012bba",
  "Lidija",
  "Liene",
  "L\u012bga",
  "Ligita",
  "Lilija",
  "Lilita",
  "L\u012bna",
  "Linda",
  "L\u012bza",
  "Lizete",
  "L\u016bcija",
  "Madara",
  "Made",
  "Maija",
  "M\u0101ra",
  "Mare",
  "Margareta",
  "Margrieta",
  "Marija",
  "M\u0101r\u012bte",
  "Marta",
  "Ma\u017ea",
  "Milda",
  "Minna",
  "Mirdza",
  "Monika",
  "Nat\u0101lija",
  "Olga",
  "Ot\u012blija",
  "Paula",
  "Paul\u012bna",
  "Rasma",
  "Reg\u012bna",
  "Rita",
  "Rud\u012bte",
  "Ruta",
  "Rute",
  "Samanta",
  "Sandra",
  "Sanita",
  "Santa",
  "Sapa",
  "Sarm\u012bte",
  "Silvija",
  "Sintija",
  "Skaidr\u012bte",
  "Solvita",
  "Tekla",
  "Tr\u012bne",
  "Valda",
  "Valent\u012bna",
  "Valija",
  "Velta",
  "Veneranda",
  "Vera",
  "Veronika",
  "Vija",
  "Vilma",
  "Vineta",
  "Vita",
  "Zane",
  "Zelma",
  "Zenta",
  "Zigr\u012bda"
)

person_last_names_lv_lv = c(
  "\u0100bele",
  "\u0100boli\u0146\u0161",
  "\u0100bols",
  "Alksnis",
  "Apinis",
  "Aps\u012btis",
  "Auni\u0146\u0161",
  "Auzi\u0146\u0161",
  "Avoti\u0146\u0161",
  "Balodis",
  "Balti\u0146\u0161",
  "B\u0113rzi\u0146\u0161",
  "Birznieks",
  "Bite",
  "Briedis",
  "Caune",
  "Celmi\u0146\u0161",
  "Celms",
  "C\u012brulis",
  "Dzenis",
  "D\u016bmi\u0146\u0161",
  "Egl\u012btis",
  "Jaunzems",
  "Kal\u0113js",
  "Kalni\u0146\u0161",
  "Ka\u0146eps",
  "K\u0101rkli\u0146\u0161",
  "Kauli\u0146\u0161",
  "K\u013cavi\u0146\u0161",
  "Krasti\u0146\u0161",
  "Kr\u0113sli\u0146\u0161",
  "Krievi\u0146\u0161",
  "Krievs",
  "Kr\u016bmi\u0146\u0161",
  "Kr\u016bze",
  "Kundzi\u0146\u0161",
  "L\u0101cis",
  "Lagzdi\u0146\u0161",
  "Lapsa",
  "L\u012bcis",
  "Liepa",
  "Liepi\u0146\u0161",
  "Luksti\u0146\u0161",
  "L\u016bsis",
  "Paegle",
  "P\u0113rkons",
  "Podnieks",
  "Polis",
  "Priede",
  "Pried\u012btis",
  "Puri\u0146\u0161",
  "Purmals",
  "Rieksti\u0146\u0161",
  "Roze",
  "Roz\u012btis",
  "Rubenis",
  "Rudz\u012btis",
  "Saul\u012btis",
  "Sili\u0146\u0161",
  "Skuja",
  "Skuji\u0146\u0161",
  "Spro\u0123is",
  "Strazdi\u0146\u0161",
  "Turi\u0146\u0161",
  "Vanags",
  "V\u012bksna",
  "Vilci\u0146\u0161",
  "Vilks",
  "V\u012btoli\u0146\u0161",
  "V\u012btols",
  "Za\u0137is",
  "Z\u0101l\u012btis",
  "Zari\u0146\u0161",
  "Zelti\u0146\u0161",
  "Ziemelis",
  "Zirnis",
  "Zvaigzne",
  "Zvirbulis"
)

person_lv_lv <- list(
  first_names = person_first_names_lv_lv,
  last_names = person_last_names_lv_lv
)

==> charlatan_0.4.0.tar.gz: charlatan/R/person-provider-lv_LV.R <==
# modified from the python library faker:
# https://github.com/joke2k/faker/blob/master/faker/providers/person/lv_LV/__init__.py

person_formats_lv_lv = c(
  '{{first_names}} {{last_names}}',
  '{{first_names}} {{last_names}}',
  '{{last_names}}, {{first_names}}'
)

person_first_names_male_lv_lv = c(
  "\u0100dams",
  "\u0100dolfs",
  "Agris",
  "Aigars",
  "Ain\u0101rs",
  "Aivars",
  "Alberts",
  "Aldis",
  "Aleksandrs",
  "Alfr\u0113ds",
  "Andrejs",
  "Andris",
  "Ansis",
  "Antons",
  "Armands",
  "Arnis",
  "Arnolds",
  "Artis",
  "Arturs",
  "Art\u016brs",
  "Arv\u012bds",
  "Augusts",
  "B\u0113rends",
  "B\u0113rtulis",
  "Brencis",
  "Dainis",
  "Daniels",
  "D\u0101vis",
  "Dzintars",
  "Edgars",
  "Edmunds",
  "Eduards",
  "Edv\u012bns",
  "Egils",
  "Elm\u0101rs",
  "Elvis",
  "Em\u012bls",
  "\u0112riks",
  "Ermanis",
  "Ernests",
  "\u0112valds",
  "Fricis",
  "Gatis",
  "Gun\u0101rs",
  "Guntars",
  "Guntis",
  "\u0122ederts",
  "\u0122irts",
  "Hanss",
  "Harijs",
  "Henriks",
  "Hermanis",
  "Igors",
  "Ilm\u0101rs",
  "Imants",
  "Indri\u0137is",
  "Ivars",
  "Ivo",
  "Jakobs",
  "Jans",
  "J\u0101nis",
  "J\u0101zeps",
  "J\u0113kabs",
  "J\u0113kaubs",
  "Jezups",
  "Johans",
  "J\u016blijs",
  "Juris",
  "K\u0101rlis",
  "Kaspars",
  "Konrads",
  "Kristaps",
  "Kristers",
  "Krists",
  "Kri\u0161j\u0101nis",
  "Kri\u0161s",
  "Laimonis",
  "Lauris",
  "Leons",
  "Maksis",
  "Mareks",
  "M\u0101ris",
  "M\u0101rti\u0146\u0161",
  "Mat\u012bss",
  "Mihels",
  "Mikels",
  "Mi\u0137elis",
  "Modris",
  "Nikolajs",
  "Niks",
  "Normunds",
  "O\u013c\u0123erts",
  "Oskars",
  "Osvalds",
  "Otto",
  "Pauls",
  "P\u0113teris",
  "Raimonds",
  "Raivis",
  "Reinis",
  "Ri\u010dards",
  "Rihards",
  "Roberts",
  "Rolands",
  "R\u016bdolfs",
  "Sandis",
  "Sta\u0146islavs",
  "Tenis",
  "Teodors",
  "Toms",
  "Uldis",
  "Valdis",
  "Viesturs",
  "Viktors",
  "Vilis",
  "Vilnis",
  "Vi\u013cums",
  "Visvaldis",
  "Vladislavs",
  "Voldem\u0101rs",
  "Ziedonis",
  "\u017danis"
)

person_first_names_female_lv_lv = c(
  "Agnese",
  "Aiga",
  "Aija",
  "Aina",
  "Al\u012bda",
  "Alise",
  "Alma",
  "Alv\u012bne",
  "Am\u0101lija",
  "Anete",
  "Anita",
  "Anna",
  "Annija",
  "Anto\u0146ina",
  "Antra",
  "\u0100rija",
  "Ausma",
  "Austra",
  "Baiba",
  "Berta",
  "Biruta",
  "Bro\u0146islava",
  "Dace",
  "Daiga",
  "Daina",
  "D\u0101rta",
  "Di\u0101na",
  "Doroteja",
  "Dzidra",
  "Dzintra",
  "Eda",
  "Ed\u012bte",
  "El\u012bna",
  "Elita",
  "Elizabete",
  "Elv\u012bra",
  "Elza",
  "Em\u012blija",
  "Emma",
  "\u0112rika",
  "Erna",
  "Eva",
  "Evija",
  "Evita",
  "Gaida",
  "Genovefa",
  "Gr\u0113ta",
  "Grieta",
  "Gunita",
  "Gunta",
  "Hel\u0113na",
  "Ieva",
  "Ilga",
  "Ilona",
  "Ilze",
  "Ina",
  "In\u0101ra",
  "Indra",
  "Inese",
  "Ineta",
  "Inga",
  "Ingr\u012bda",
  "Inguna",
  "Inta",
  "Ir\u0113na",
  "Irma",
  "Iveta",
  "Jana",
  "Janina",
  "J\u016ble",
  "J\u016bla",
  "J\u016blija",
  "Karina",
  "Karl\u012bna",
  "Katar\u012bna",
  "Katr\u012bna",
  "Krista",
  "Kristi\u0101na",
  "Laila",
  "Laura",
  "Lav\u012bze",
  "Leont\u012bne",
  "L\u012bba",
  "Lidija",
  "Liene",
  "L\u012bga",
  "Ligita",
  "Lilija",
  "Lilita",
  "L\u012bna",
  "Linda",
  "L\u012bza",
  "Lizete",
  "L\u016bcija",
  "Madara",
  "Made",
  "Maija",
  "M\u0101ra",
  "Mare",
  "Margareta",
  "Margrieta",
  "Marija",
  "M\u0101r\u012bte",
  "Marta",
  "Milda",
  "Minna",
  "Mirdza",
  "Monika",
  "Nat\u0101lija",
  "Olga",
  "Ot\u012blija",
  "Paula",
  "Paul\u012bna",
  "Rasma",
  "Reg\u012bna",
  "Rita",
  "Rud\u012bte",
  "Ruta",
  "Rute",
  "Samanta",
  "Sandra",
  "Sanita",
  "Santa",
  "Sarm\u012bte",
  "Silvija",
  "Sintija",
  "Skaidr\u012bte",
  "Solvita",
  "Tekla",
  "Tr\u012bne",
  "Valda",
  "Valent\u012bna",
  "Valija",
  "Velta",
  "Veneranda",
  "Vera",
  "Veronika",
  "Vija",
  "Vilma",
  "Vineta",
  "Vita",
  "Zane",
  "Zelma",
  "Zenta",
  "Zigr\u012bda"
)

person_last_names_male_lv_lv = c(
  "\u0100bele",
  "\u0100boli\u0146\u0161",
  "\u0100bols",
  "Alksnis",
  "Apinis",
  "Aps\u012btis",
  "Auni\u0146\u0161",
  "Auzi\u0146\u0161",
  "Avoti\u0146\u0161",
  "Balodis",
  "Balti\u0146\u0161",
  "B\u0113rzi\u0146\u0161",
  "Birznieks",
  "Bite",
  "Briedis",
  "Caune",
  "Celmi\u0146\u0161",
  "Celms",
  "C\u012brulis",
  "Dzenis",
  "D\u016bmi\u0146\u0161",
  "Egl\u012btis",
  "Jaunzems",
  "Kal\u0113js",
  "Kalni\u0146\u0161",
  "Ka\u0146eps",
  "K\u0101rkli\u0146\u0161",
  "Kauli\u0146\u0161",
  "K\u013cavi\u0146\u0161",
  "Krasti\u0146\u0161",
  "Kr\u0113sli\u0146\u0161",
  "Krievi\u0146\u0161",
  "Krievs",
  "Kr\u016bmi\u0146\u0161",
  "Kr\u016bze",
  "Kundzi\u0146\u0161",
  "L\u0101cis",
  "Lagzdi\u0146\u0161",
  "Lapsa",
  "L\u012bcis",
  "Liepa",
  "Liepi\u0146\u0161",
  "Luksti\u0146\u0161",
  "L\u016bsis",
  "Paegle",
  "P\u0113rkons",
  "Podnieks",
  "Polis",
  "Priede",
  "Pried\u012btis",
  "Puri\u0146\u0161",
  "Purmals",
  "Rieksti\u0146\u0161",
  "Roze",
  "Roz\u012btis",
  "Rubenis",
  "Rudz\u012btis",
  "Saul\u012btis",
  "Sili\u0146\u0161",
  "Skuja",
  "Skuji\u0146\u0161",
  "Spro\u0123is",
  "Strazdi\u0146\u0161",
  "Turi\u0146\u0161",
  "Vanags",
  "V\u012bksna",
  "Vilci\u0146\u0161",
  "Vilks",
  "V\u012btoli\u0146\u0161",
  "V\u012btols",
  "Za\u0137is",
  "Z\u0101l\u012btis",
  "Zari\u0146\u0161",
  "Zelti\u0146\u0161",
  "Ziemelis",
  "Zirnis",
  "Zvaigzne",
  "Zvirbulis"
)

person_last_names_female_lv_lv = c(
  "\u0100bele",
  "\u0100boli\u0146a",
  "\u0100bola",
  "Alksne",
  "Apine",
  "Aps\u012bte",
  "Auni\u0146a",
  "Auzi\u0146a",
  "Avoti\u0146a",
  "Balode",
  "Balti\u0146a",
  "B\u0113rzi\u0146a",
  "Birzniece",
  "Bite",
  "Briede",
  "Caune",
  "Celmi\u0146a",
  "Celma",
  "C\u012brule",
  "Dzene",
  "D\u016bmi\u0146a",
  "Egl\u012bte",
  "Jaunzema",
  "Kal\u0113ja",
  "Kalni\u0146a",
  "Ka\u0146epa",
  "K\u0101rkli\u0146a",
  "Kauli\u0146a",
  "K\u013cavi\u0146a",
  "Krasti\u0146a",
  "Kr\u0113sli\u0146a",
  "Krievi\u0146a",
  "Krieva",
  "Kr\u016bmi\u0146a",
  "Kr\u016bze",
  "Kundzi\u0146a",
  "L\u0101ce",
  "Lagzdi\u0146a",
  "Lapsa",
  "L\u012bce",
  "Liepa",
  "Liepi\u0146a",
  "Luksti\u0146a",
  "L\u016bse",
  "Paegle",
  "P\u0113rkona",
  "Podnieka",
  "Pole",
  "Priede",
  "Pried\u012bte",
  "Puri\u0146a",
  "Purmala",
  "Rieksti\u0146a",
  "Roze",
  "Roz\u012bte",
  "Rubene",
  "Rudz\u012bte",
  "Saul\u012bte",
  "Sili\u0146a",
  "Skuja",
  "Skuji\u0146a",
  "Spro\u0123e",
  "Strazdi\u0146a",
  "Turi\u0146a",
  "Vanaga",
  "V\u012bksna",
  "Vilci\u0146a",
  "Vilka",
  "V\u012btoli\u0146a",
  "V\u012btola",
  "Za\u0137e",
  "Z\u0101l\u012bte",
  "Zari\u0146a",
  "Zelti\u0146a",
  "Ziemele",
  "Zirne",
  "Zvaigzne",
  "Zvirbule"
)

person_last_names_lv_lv = c(person_last_names_male_lv_lv, person_last_names_female_lv_lv)

person_formats_female_lv_lv = c(
  '{{first_names_female}} {{last_names_female}}',
  '{{first_names_female}} {{last_names_female}}'
)

person_formats_male_lv_lv = c(
  '{{first_names_male}} {{last_names_male}}',
  '{{first_names_male}} {{last_names_male}}'
)

person_formats_lv_lv = c(person_formats_male_lv_lv, person_formats_female_lv_lv)
person_first_names_lv_lv = c(person_first_names_male_lv_lv, person_first_names_female_lv_lv)

person_lv_lv <- list(
  first_names = person_first_names_lv_lv,
  first_names_male = person_first_names_male_lv_lv,
  first_names_female = person_first_names_female_lv_lv,
  last_names_male = person_last_names_male_lv_lv,
  last_names_female = person_last_names_female_lv_lv
)
